//
//  MSCommandGroup.h
//  MSCommandsManager
//
//  Created by Paul Herzog on 17-Sep-2007.
//  Copyright 2007 MacSpeech, Inc. All rights reserved.
//

#import <Cocoa/Cocoa.h>

// Types of active state for a group of commands
typedef enum {
   kMSCommandGroupActiveStateUnknown,
   kMSCommandGroupActiveStateInactive,
   kMSCommandGroupActiveStateActive,
   kMSCommandGroupActiveStateMixed
} MSCommandGroupActiveState;

typedef enum {
	kMSGroupTypeCommands,
	kMSGroupTypeNotes
} MSGroupType;

@interface MSCommandGroup : NSObject {
   NSString *name;
   MSCommandGroupActiveState activeState;
   NSArray *commands;
   unsigned int commandCount;
   MSGroupType groupType;
   NSString *key;
   NSString *groupDescription;
   NSDictionary *applicationInformation;
   NSMutableArray *subGroups;
   NSString *groupCategory;
}

#pragma mark
#pragma mark Initialization
- (id)initWithName:(NSString *)groupName commands:(NSArray *)groupCommands activeState:(MSCommandGroupActiveState)groupActiveState;
- (id)initWithName:(NSString *)groupName content:(NSArray *)groupContent key:groupKey description:(NSString *)description;
- (NSArray *)visibleCommandsInList:(NSArray *)commandList;

#pragma mark
#pragma mark Accessors
- (void)addSubGroup:(MSCommandGroup *)subGroup;
- (BOOL)didRemoveSubGroupName:(NSString *)subGroupName;

- (NSString *)name;
- (void)setName:(NSString *)groupName;

- (MSCommandGroupActiveState)activeState;
- (void)setActiveState:(MSCommandGroupActiveState)groupActiveState;

- (NSArray *)subGroups;
- (NSArray *)commands;
- (void)setCommands:(NSArray *)groupCommands;
- (void)setContent:(NSArray *)groupContent;

- (MSGroupType)groupType;
- (void)setGroupType:(MSGroupType)value;

- (NSString *)key;
- (void)setKey:(NSString *)value;

- (NSString *)groupDescription;
- (void)setGroupDescription:(NSString *)value;

- (BOOL)isGeneratedCommandGroup;

- (NSString *)groupCategory;
- (void)setGroupCategory:(NSString *)value;

- (BOOL)hasGlobalGroupCategory;

#pragma mark
#pragma mark Display Filter
- (NSDictionary *)commandsIndexedByTriggerFilteredBy:(SEL)commandFilter inTarget:(NSObject *)target;
+ (NSArray *)displayableCommands:(NSArray *)commands;
- (NSString *)groupCategoryFromText:(NSString *)text;
- (NSString *)filteredDescriptionFromText:(NSString *)text;
    

- (unsigned int)countOfCommands;
- (CommandMO *)objectInCommandsAtIndex:(unsigned int)index;
- (NSObject *)itemAtIndex:(unsigned int)index;
- (unsigned int)numberOfItems;
- (unsigned int)numberOfSubGroups;
- (BOOL)hasSubGroups;


- (NSDictionary *)applicationInformation;
- (void)setApplicationInformation:(NSDictionary *)appInfo;
- (NSString *)appBundle;
- (NSNumber *)appVersion;
+ (MSCommandGroup *)emptyGlobalGroupNamed:(NSString *)groupName;

@end
